Paragraph

Struct Paragraph 

pub struct Paragraph(/* private fields */);
An AST node representing a Paragraph.

Implementations

Source

impl Paragraph

pub fn new() -> Paragraph

Create a new empty paragraph.

pub fn wrap_and_sort( &self, indentation: Indentation, immediate_empty_line: bool, max_line_length_one_liner: Option<usize>, sort_entries: Option<&dyn Fn(&Entry, &Entry) -> Ordering>, format_value: Option<&dyn Fn(&str, &str) -> String>, ) -> Paragraph

Reformat this paragraph

Arguments
  • indentation - The indentation to use
  • immediate_empty_line - Whether multi-line values should always start with an empty line
  • max_line_length_one_liner - If set, then this is the max length of the value if it is crammed into a “one-liner” value
  • sort_entries - If set, then this function will sort the entries according to the given function
  • format_value - If set, then this function will format the value according to the given function
pub fn get(&self, key: &str) -> Option<String>

Returns the value of the given key in the paragraph.

pub fn contains_key(&self, key: &str) -> bool

Returns whether the paragraph contains the given key.

pub fn entries(&self) -> impl Iterator<Item = Entry> + '_

Returns an iterator over all entries in the paragraph.

pub fn items(&self) -> impl Iterator<Item = (String, String)> + '_

Returns an iterator over all items in the paragraph.

pub fn get_all<'a>(&'a self, key: &'a str) -> impl Iterator<Item = String> + 'a

Returns an iterator over all values for the given key in the paragraph.

pub fn keys(&self) -> impl Iterator<Item = String> + '_

Returns an iterator over all keys in the paragraph.

pub fn remove(&mut self, key: &str)

Remove the given field from the paragraph.

pub fn insert(&mut self, key: &str, value: &str)

Insert a new field

pub fn set(&mut self, key: &str, value: &str)

Set a field in the paragraph

pub fn rename(&mut self, old_key: &str, new_key: &str) -> bool

Rename the given field in the paragraph.